==> esp8266-0.3.0.crate: esp8266-0.3.0/src/spi0/spi_ext1.rs <==
#[doc = "Register `SPI_EXT1` reader"]
pub struct R(crate::R<SPI_EXT1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SPI_EXT1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<SPI_EXT1_SPEC>> for R {
    fn from(reader: crate::R<SPI_EXT1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SPI_EXT1` writer"]
pub struct W(crate::W<SPI_EXT1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SPI_EXT1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<SPI_EXT1_SPEC>> for W {
    fn from(writer: crate::W<SPI_EXT1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `erase_enable` reader - "]
pub struct ERASE_ENABLE_R(crate::FieldReader<bool, bool>);
impl ERASE_ENABLE_R {
    pub(crate) fn new(bits: bool) -> Self {
        ERASE_ENABLE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for ERASE_ENABLE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `erase_enable` writer - "]
pub struct ERASE_ENABLE_W<'a> {
    w: &'a mut W,
}
impl<'a> ERASE_ENABLE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 31)) | (((value as u32) & 0x01) << 31);
        self.w
    }
}
#[doc = "Field `erase_shift` reader - "]
pub struct ERASE_SHIFT_R(crate::FieldReader<u8, u8>);
impl ERASE_SHIFT_R {
    pub(crate) fn new(bits: u8) -> Self {
        ERASE_SHIFT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for ERASE_SHIFT_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `erase_shift` writer - "]
pub struct ERASE_SHIFT_W<'a> {
    w: &'a mut W,
}
impl<'a> ERASE_SHIFT_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x0f << 16)) | (((value as u32) & 0x0f) << 16);
        self.w
    }
}
#[doc = "Field `erase_time` reader - "]
pub struct ERASE_TIME_R(crate::FieldReader<u16, u16>);
impl ERASE_TIME_R {
    pub(crate) fn new(bits: u16) -> Self {
        ERASE_TIME_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for ERASE_TIME_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `erase_time` writer - "]
pub struct ERASE_TIME_W<'a> {
    w: &'a mut W,
}
impl<'a> ERASE_TIME_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | ((value as u32) & 0x0fff);
        self.w
    }
}
impl R {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn erase_enable(&self) -> ERASE_ENABLE_R {
        ERASE_ENABLE_R::new(((self.bits >> 31) & 0x01) != 0)
    }
    #[doc = "Bits 16:19"]
    #[inline(always)]
    pub fn erase_shift(&self) -> ERASE_SHIFT_R {
        ERASE_SHIFT_R::new(((self.bits >> 16) & 0x0f) as u8)
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn erase_time(&self) -> ERASE_TIME_R {
        ERASE_TIME_R::new((self.bits & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn erase_enable(&mut self) -> ERASE_ENABLE_W {
        ERASE_ENABLE_W { w: self }
    }
    #[doc = "Bits 16:19"]
    #[inline(always)]
    pub fn erase_shift(&mut self) -> ERASE_SHIFT_W {
        ERASE_SHIFT_W { w: self }
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn erase_time(&mut self) -> ERASE_TIME_W {
        ERASE_TIME_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ext1](index.html) module"]
pub struct SPI_EXT1_SPEC;
impl crate::RegisterSpec for SPI_EXT1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [spi_ext1::R](R) reader structure"]
impl crate::Readable for SPI_EXT1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [spi_ext1::W](W) writer structure"]
impl crate::Writable for SPI_EXT1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SPI_EXT1 to value 0"]
impl crate::Resettable for SPI_EXT1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/spi0/spi_ext1.rs <==
#[doc = "Register `SPI_EXT1` reader"]
pub struct R(crate::R<SPI_EXT1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SPI_EXT1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SPI_EXT1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SPI_EXT1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SPI_EXT1` writer"]
pub struct W(crate::W<SPI_EXT1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SPI_EXT1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SPI_EXT1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SPI_EXT1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `erase_enable` reader - "]
pub struct ERASE_ENABLE_R(crate::FieldReader<bool, bool>);
impl ERASE_ENABLE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        ERASE_ENABLE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for ERASE_ENABLE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `erase_enable` writer - "]
pub struct ERASE_ENABLE_W<'a> {
    w: &'a mut W,
}
impl<'a> ERASE_ENABLE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
        self.w
    }
}
#[doc = "Field `erase_shift` reader - "]
pub struct ERASE_SHIFT_R(crate::FieldReader<u8, u8>);
impl ERASE_SHIFT_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        ERASE_SHIFT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for ERASE_SHIFT_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `erase_shift` writer - "]
pub struct ERASE_SHIFT_W<'a> {
    w: &'a mut W,
}
impl<'a> ERASE_SHIFT_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x0f << 16)) | ((value as u32 & 0x0f) << 16);
        self.w
    }
}
#[doc = "Field `erase_time` reader - "]
pub struct ERASE_TIME_R(crate::FieldReader<u16, u16>);
impl ERASE_TIME_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        ERASE_TIME_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for ERASE_TIME_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `erase_time` writer - "]
pub struct ERASE_TIME_W<'a> {
    w: &'a mut W,
}
impl<'a> ERASE_TIME_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | (value as u32 & 0x0fff);
        self.w
    }
}
impl R {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn erase_enable(&self) -> ERASE_ENABLE_R {
        ERASE_ENABLE_R::new(((self.bits >> 31) & 0x01) != 0)
    }
    #[doc = "Bits 16:19"]
    #[inline(always)]
    pub fn erase_shift(&self) -> ERASE_SHIFT_R {
        ERASE_SHIFT_R::new(((self.bits >> 16) & 0x0f) as u8)
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn erase_time(&self) -> ERASE_TIME_R {
        ERASE_TIME_R::new((self.bits & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn erase_enable(&mut self) -> ERASE_ENABLE_W {
        ERASE_ENABLE_W { w: self }
    }
    #[doc = "Bits 16:19"]
    #[inline(always)]
    pub fn erase_shift(&mut self) -> ERASE_SHIFT_W {
        ERASE_SHIFT_W { w: self }
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn erase_time(&mut self) -> ERASE_TIME_W {
        ERASE_TIME_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ext1](index.html) module"]
pub struct SPI_EXT1_SPEC;
impl crate::RegisterSpec for SPI_EXT1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [spi_ext1::R](R) reader structure"]
impl crate::Readable for SPI_EXT1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [spi_ext1::W](W) writer structure"]
impl crate::Writable for SPI_EXT1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SPI_EXT1 to value 0"]
impl crate::Resettable for SPI_EXT1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
